@@ -117,9 +117,9 @@ sub _create_upstream_repo ($self) {
         }
     );
 
-    my $upstream_api = $scm_upstream->get_upstream_api;
+    my $hosting_api = $scm_upstream->get_hosting_api;
 
-    my $create_res = $upstream_api->create_repo( $upstream_repo_id, is_private => $self->{is_private}, scm => $self->{upstream_scm_type} );
+    my $create_res = $hosting_api->create_repo( $upstream_repo_id, is_private => $self->{is_private}, scm => $self->{upstream_scm_type} );
 
     say $create_res;
 
@@ -130,7 +130,7 @@ sub _create_upstream_repo ($self) {
 
     print qq[Cloning upstream repository "$clone_uri" ... ];
 
-    my $clone_res = Pcore::API::SCM->scm_clone( $self->target_path, $clone_uri, $self->{local_scm_type} );
+    my $clone_res = Pcore::API::SCM->scm_clone( $clone_uri, $self->target_path, $self->{local_scm_type} );
 
     say $clone_res;
 
